To contribute, fork this repo and submit your changes via a pull-request.
Before sending pull-request, check the following:

- [ ] Software builds locally
- [ ] `ctest --output-on-failure` passes all tests.
